@@ -225,7 +225,7 @@ pulseaudio_notify_notify (PulseaudioNotify *notify, gboolean mic)
     {
       notify_notification_set_hint (notification,
                                     "value",
-                                    g_variant_new_int32(volume_i));
+                                    g_variant_new_int32 (MIN (100, volume_i)));
       notify_notification_set_hint (notification,
                                     "x-canonical-private-synchronous",
                                     g_variant_new_string(""));
@@ -285,7 +285,7 @@ pulseaudio_notify_new (PulseaudioConfig *config,
   notify->volume_changed_id =
     g_signal_connect_swapped (G_OBJECT (notify->volume), "volume-changed",
                               G_CALLBACK (pulseaudio_notify_volume_changed), notify);
-  notify->volume_changed_id =
+  notify->volume_mic_changed_id =
     g_signal_connect_swapped (G_OBJECT (notify->volume), "volume-mic-changed",
                               G_CALLBACK (pulseaudio_notify_volume_mic_changed), notify);
 
