@@ -98,7 +98,8 @@ static void         scale_menu_item_parent_set              (GtkWidget
 GtkWidget*
 scale_menu_item_new_with_range (gdouble min,
                                 gdouble max,
-                                gdouble step)
+                                gdouble step,
+                                gdouble base)
 {
   ScaleMenuItem        *scale_item;
   ScaleMenuItemPrivate *priv;
@@ -122,6 +123,9 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   gtk_scale_set_draw_value (GTK_SCALE(priv->scale), FALSE);
   gtk_range_set_round_digits(GTK_RANGE(priv->scale), 0);
 
+  if (base > 0.0 && base < max)
+    gtk_scale_add_mark (GTK_SCALE (priv->scale), base, GTK_POS_BOTTOM, NULL);
+
   if (max > 100.0)
     gtk_scale_add_mark (GTK_SCALE (priv->scale), 100.0, GTK_POS_BOTTOM, NULL);
 
